Description Usage Arguments Value
Set default theme and change geom defaults
1 2 3 4 5 6 | start_bray(
maincolor = "#e8e7e3",
offcolor = "#66696e",
gridh = TRUE,
gridv = FALSE
)
|
maincolor |
HEX color string for default objects like points, lines, ...(Default = |
offcolor |
HEX color string for secondary objects like gridlines, axes, ...(Default = |
gridh |
Bool flag for major horizontal gridlines (Default = |
gridv |
Bool flag for major vertical gridlines (Default = |
Nothing
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.