theme_bray: Theme object for ggplot2

Description Usage Arguments Value Examples

View source: R/theme_bray.R

Description

Theme object for ggplot2

Usage

1
2
3
4
5
6
7
8
theme_bray(
  maincolor = "#e8e7e3",
  altcolor = "#d5bd5e",
  bgcolor = "#1b1d24",
  offcolor = "#66696e",
  gridh = TRUE,
  gridv = FALSE
)

Arguments

maincolor

HEX color string for default objects like points, lines, ...(Default = "#e8e7e3")

altcolor

HEX color string for emphasis objects like point subsets, ...(Default = "#d5bd5e")

bgcolor

HEX color string for background (Default = "#1b1d24") doesn't affect export

offcolor

HEX color string for secondary objects like gridlines, axes, ...(Default = "#66696e")

gridh

Bool flag for major horizontal gridlines (Default = TRUE)

gridv

Bool flag for major vertical gridlines (Default = FALSE)

Value

Theme object

Examples

1
theme_bray(gridh = FALSE)

fr-pscz/theme_bray documentation built on Dec. 20, 2021, 8:50 a.m.