Description Usage Arguments Value Examples
Theme object for ggplot2
1 2 3 4 5 6 7 8 | theme_bray(
maincolor = "#e8e7e3",
altcolor = "#d5bd5e",
bgcolor = "#1b1d24",
offcolor = "#66696e",
gridh = TRUE,
gridv = FALSE
)
|
maincolor |
HEX color string for default objects like points, lines, ...(Default = |
altcolor |
HEX color string for emphasis objects like point subsets, ...(Default = |
bgcolor |
HEX color string for background (Default = |
offcolor |
HEX color string for secondary objects like gridlines, axes, ...(Default = |
gridh |
Bool flag for major horizontal gridlines (Default = |
gridv |
Bool flag for major vertical gridlines (Default = |
Theme object
1 | theme_bray(gridh = FALSE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.